summaryrefslogtreecommitdiff
path: root/chrome/browser/signin/screenlock_bridge.h
diff options
context:
space:
mode:
authorTorne (Richard Coles) <torne@google.com>2014-06-03 10:58:34 +0100
committerTorne (Richard Coles) <torne@google.com>2014-06-03 10:58:34 +0100
commitcedac228d2dd51db4b79ea1e72c7f249408ee061 (patch)
treeaa4ff43d7fe316e95d12721ce5e17653a768a0dd /chrome/browser/signin/screenlock_bridge.h
parent6a869ecff032b5bed299d661b078b0555034598b (diff)
downloadchromium_org-cedac228d2dd51db4b79ea1e72c7f249408ee061.tar.gz
Merge from Chromium at DEPS revision 273901
This commit was generated by merge_to_master.py. Change-Id: I45745444894df927ffc1045ab8de88b9e52636a3
Diffstat (limited to 'chrome/browser/signin/screenlock_bridge.h')
-rw-r--r--chrome/browser/signin/screenlock_bridge.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/chrome/browser/signin/screenlock_bridge.h b/chrome/browser/signin/screenlock_bridge.h
index cce1b7c295..6e82317f30 100644
--- a/chrome/browser/signin/screenlock_bridge.h
+++ b/chrome/browser/signin/screenlock_bridge.h
@@ -5,7 +5,8 @@
#ifndef CHROME_BROWSER_SIGNIN_SCREENLOCK_BRIDGE_H_
#define CHROME_BROWSER_SIGNIN_SCREENLOCK_BRIDGE_H_
-#include "base/callback_forward.h"
+#include <string>
+
#include "base/lazy_instance.h"
#include "base/macros.h"
#include "base/observer_list.h"
@@ -45,14 +46,12 @@ class ScreenlockBridge {
// Displays |message| in a banner on the lock screen.
virtual void ShowBannerMessage(const std::string& message) = 0;
- // Shows a button inside the user pod on the lock screen with an icon.
- // |callback| is invoked when the icon is clicked. This is deprecated now.
- virtual void ShowUserPodButton(const std::string& user_email,
- const gfx::Image& icon,
- const base::Closure& callback) = 0;
+ // Shows a custom icon in the user pod on the lock screen.
+ virtual void ShowUserPodCustomIcon(const std::string& user_email,
+ const gfx::Image& icon) = 0;
- // Hides the user pod button for a user.
- virtual void HideUserPodButton(const std::string& user_email) = 0;
+ // Hides the custom icon in user pod for a user.
+ virtual void HideUserPodCustomIcon(const std::string& user_email) = 0;
// (Re)enable lock screen UI.
virtual void EnableInput() = 0;